# -*- coding: utf-8 -*-
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Script that shows the qt gui."""

import sys

if sys.platform != 'win32':
    # pylint: disable=F0401
    from twisted.internet import glib2reactor
    glib2reactor.install()

    from dbus.mainloop.glib import DBusGMainLoop
    DBusGMainLoop(set_as_default=True)

from twisted.internet import defer, reactor

from ubuntu_sso.main import get_sso_client
from ubuntu_sso.credentials import (
     TC_URL_KEY,
     HELP_TEXT_KEY,
     WINDOW_ID_KEY,
     UI_MODULE_KEY,
)

# pylint: disable=E1101


@defer.inlineCallbacks
def main():
    """Perform a client request to be logged in."""
    d = defer.Deferred()
    client = yield get_sso_client()

    def found(*args):
        """The result was received."""
        print "result received", args
        d.callback(args)

    client.cred_manager.connect_to_signal('CredentialsFound', found)
    client.cred_manager.connect_to_signal('CredentialsNotFound', found)
    client.cred_manager.connect_to_signal('AuthorizationDenied', found)
    client.cred_manager.connect_to_signal('CredentialsError', found)

    yield client.cred_manager.login('Ubuntu One',
        {
            TC_URL_KEY: 'http://www.google.com',
            HELP_TEXT_KEY: 'This is a test.',
            WINDOW_ID_KEY: '0',
            UI_MODULE_KEY: 'ubuntu_sso.qt.gui',
        })
    print "called ok"
    yield d

    yield client.disconnect()
    reactor.stop()


if __name__ == '__main__':
    main()
    reactor.run()
